See the [release notes](https://docs.popv.org/en/stable/changelog.html) for all changes.

This release is available via PyPi:

```bash
pip install popv
```

Please report any issues on [GitHub](https://github.com/yoseflab/popv).
